@@ -36,6 +36,7 @@ def run_clustering_experiment(
     cls_name=None,
     dataset_name=None,
     resample_id=0,
+    overwrite=True,
 ):
     """
     Run a clustering experiment and save the results to file.
@@ -74,59 +75,86 @@ def run_clustering_experiment(
         Resample identifier, defaults to 0
 
     """
-    # Build the clusterer on train data, recording how long it takes
+    if not overwrite:
+        full_path = (
+            results_path
+            + "/"
+            + cls_name
+            + "/Predictions/"
+            + dataset_name
+            + "/testResample"
+            + str(resample_id)
+            + ".csv"
+        )
+        if os.path.exists(full_path):
+            return
 
+    # Build the clusterer on train data, recording how long it takes
+    le = preprocessing.LabelEncoder()
+    le.fit(trainY)
+    trainY = le.transform(trainY)
+    testY = le.transform(testY)
     start = int(round(time.time() * 1000))
     clusterer.fit(trainX)
     build_time = int(round(time.time() * 1000)) - start
     start = int(round(time.time() * 1000))
     train_preds = clusterer.predict(trainX)
-    # predict_train_time = int(round(time.time() * 1000)) - start
+    build_time = int(round(time.time() * 1000)) - start
+    train_probs = clusterer.predict_proba(trainX)
 
-    # Form predictions on trainY
     start = int(round(time.time() * 1000))
-    preds = clusterer.predict(testX)
+    test_preds = clusterer.predict(testX)
     test_time = int(round(time.time() * 1000)) - start
+    test_probs = clusterer.predict_proba(testX)
     second = str(clusterer.get_params())
     second.replace("\n", " ")
     second.replace("\r", " ")
-    # TODO: refactor clusterers to return an array
-    pr = np.array(preds)
-    third = "," + str(build_time) + "," + str(test_time) + ",-1,-1,"
+    third = "0," + str(build_time) + "," + str(test_time) + ",-1,-1," "" + str(
+        len(np.unique(trainY))
+    ) + "," + str(len(np.unique(trainY)))
     write_results_to_uea_format(
+        first_line_comment="Generated by clustering_experiments on "
+        + str(datetime.today()),
         second_line=second,
         third_line=third,
         output_path=results_path,
         estimator_name=cls_name,
         resample_seed=resample_id,
-        y_pred=pr,
+        y_pred=test_preds,
+        predicted_probs=test_probs,
         dataset_name=dataset_name,
         y_true=testY,
         split="TEST",
         full_path=False,
+        timing_type="MILLISECONDS",
     )
 
     #        preds = form_cluster_list(clusters, len(testY))
     if "Composite" in cls_name:
         second = "Para info too long!"
     else:
-
         second = str(clusterer.get_params())
         second.replace("\n", " ")
         second.replace("\r", " ")
-        third = "FORMAT NOT FINALISED"
-        write_results_to_uea_format(
-            second_line=second,
-            third_line=third,
-            output_path=results_path,
-            estimator_name=cls_name,
-            resample_seed=resample_id,
-            y_pred=train_preds,
-            dataset_name=dataset_name,
-            y_true=trainY,
-            split="TRAIN",
-            full_path=False,
-        )
+    third = "0," + str(build_time) + "," + str(test_time) + ",-1,-1," "" + str(
+        len(np.unique(trainY))
+    ) + "," + str(len(np.unique(trainY)))
+    write_results_to_uea_format(
+        first_line_comment="Generated by clustering_experiments on "
+        + str(datetime.today()),
+        second_line=second,
+        third_line=third,
+        output_path=results_path,
+        estimator_name=cls_name,
+        resample_seed=resample_id,
+        y_pred=train_preds,
+        predicted_probs=train_probs,
+        dataset_name=dataset_name,
+        y_true=trainY,
+        split="TRAIN",
+        full_path=False,
+        timing_type="MILLISECONDS",
+    )
 
 
 def load_and_run_clustering_experiment(
@@ -213,10 +241,6 @@ def load_and_run_clustering_experiment(
         trainX, trainY, testX, testY = stratified_resample(
             trainX, trainY, testX, testY, resample_id
         )
-    le = preprocessing.LabelEncoder()
-    le.fit(trainY)
-    trainY = le.transform(trainY)
-    testY = le.transform(testY)
     run_clustering_experiment(
         trainX,
         clusterer,
