@@ -122,7 +122,7 @@ class ContractableBOSS(BaseClassifier):
     >>> from sktime.datasets import load_unit_test
     >>> X_train, y_train = load_unit_test(split="train", return_X_y=True)
     >>> X_test, y_test = load_unit_test(split="test", return_X_y=True)
-    >>> clf = ContractableBOSS(n_parameter_samples=25, max_ensemble_size=5)
+    >>> clf = ContractableBOSS(n_parameter_samples=10, max_ensemble_size=3)
     >>> clf.fit(X_train, y_train)
     ContractableBOSS(...)
     >>> y_pred = clf.predict(X_test)
@@ -438,9 +438,19 @@ class ContractableBOSS(BaseClassifier):
         return correct / train_size
 
     @classmethod
-    def get_test_params(cls):
+    def get_test_params(cls, parameter_set="default"):
         """Return testing parameter settings for the estimator.
 
+        Parameters
+        ----------
+        parameter_set : str, default="default"
+            Name of the set of test parameters to return, for use in tests. If no
+            special parameters are defined for a value, will return `"default"` set.
+            For classifiers, a "default" set of parameters should be provided for
+            general testing, and a "results_comparison" set for comparing against
+            previously recorded results if the general set does not produce suitable
+            probabilities to compare against.
+
         Returns
         -------
         params : dict or list of dict, default={}
@@ -449,5 +459,7 @@ class ContractableBOSS(BaseClassifier):
             `MyClass(**params)` or `MyClass(**params[i])` creates a valid test instance.
             `create_test_instance` uses the first (or only) dictionary in `params`.
         """
-        params = {"n_parameter_samples": 4, "max_ensemble_size": 2}
-        return params
+        if parameter_set == "results_comparison":
+            return {"n_parameter_samples": 10, "max_ensemble_size": 5}
+        else:
+            return {"n_parameter_samples": 4, "max_ensemble_size": 2}
