@@ -84,7 +84,7 @@ class KNeighborsTimeSeriesClassifier(_KNeighborsClassifier, BaseClassifier):
     >>> from sktime.datasets import load_unit_test
     >>> X_train, y_train = load_unit_test(return_X_y=True, split="train")
     >>> X_test, y_test = load_unit_test(return_X_y=True, split="test")
-    >>> classifier = KNeighborsTimeSeriesClassifier()
+    >>> classifier = KNeighborsTimeSeriesClassifier(distance="euclidean")
     >>> classifier.fit(X_train, y_train)
     KNeighborsTimeSeriesClassifier(...)
     >>> y_pred = classifier.predict(X_test)
@@ -92,6 +92,7 @@ class KNeighborsTimeSeriesClassifier(_KNeighborsClassifier, BaseClassifier):
 
     _tags = {
         "capability:multivariate": True,
+        "classifier_type": "distance",
     }
 
     def __init__(
@@ -100,7 +101,7 @@ class KNeighborsTimeSeriesClassifier(_KNeighborsClassifier, BaseClassifier):
         weights="uniform",
         distance="dtw",
         distance_params=None,
-        **kwargs
+        **kwargs,
     ):
         # self._distance_params = distance_params
         # if distance_params is None:
@@ -116,7 +117,7 @@ class KNeighborsTimeSeriesClassifier(_KNeighborsClassifier, BaseClassifier):
             algorithm="brute",
             metric=distance,
             metric_params=None,  # Extra distance params handled in _fit
-            **kwargs
+            **kwargs,
         )
         BaseClassifier.__init__(self)
         self.weights = _check_weights(weights)
@@ -274,7 +275,7 @@ class KNeighborsTimeSeriesClassifier(_KNeighborsClassifier, BaseClassifier):
                 reduce_func=reduce_func,
                 metric=self.effective_metric_,
                 n_jobs=n_jobs,
-                **kwds
+                **kwds,
             )
         else:
             raise ValueError("internal: _fit_method not recognized")
@@ -312,11 +313,11 @@ class KNeighborsTimeSeriesClassifier(_KNeighborsClassifier, BaseClassifier):
                 return dist, neigh_ind
             return neigh_ind
 
-    def predict(self, X, **kwargs):
+    def predict(self, X, **kwargs) -> np.ndarray:
         """Predict wrapper."""
         return BaseClassifier.predict(self, X, **kwargs)
 
-    def _predict(self, X):
+    def _predict(self, X) -> np.ndarray:
         """Predict the class labels for the provided data.
 
         Parameters
@@ -368,11 +369,11 @@ class KNeighborsTimeSeriesClassifier(_KNeighborsClassifier, BaseClassifier):
             check_array.__code__ = temp
         return y_pred
 
-    def predict_proba(self, X, **kwargs):
+    def predict_proba(self, X, **kwargs) -> np.ndarray:
         """Predict proba wrapper."""
         return BaseClassifier.predict_proba(self, X, **kwargs)
 
-    def _predict_proba(self, X):
+    def _predict_proba(self, X) -> np.ndarray:
         """Return probability estimates for the test data X.
 
         Parameters
@@ -438,6 +439,30 @@ class KNeighborsTimeSeriesClassifier(_KNeighborsClassifier, BaseClassifier):
             check_array.__code__ = temp
         return probabilities
 
+    @classmethod
+    def get_test_params(cls, parameter_set="default"):
+        """Return testing parameter settings for the estimator.
+
+        Parameters
+        ----------
+        parameter_set : str, default="default"
+            Name of the set of test parameters to return, for use in tests. If no
+            special parameters are defined for a value, will return `"default"` set.
+            For classifiers, a "default" set of parameters should be provided for
+            general testing, and a "results_comparison" set for comparing against
+            previously recorded results if the general set does not produce suitable
+            probabilities to compare against.
+
+        Returns
+        -------
+        params : dict or list of dict, default={}
+            Parameters to create testing instances of the class.
+            Each dict are parameters to construct an "interesting" test instance, i.e.,
+            `MyClass(**params)` or `MyClass(**params[i])` creates a valid test instance.
+            `create_test_instance` uses the first (or only) dictionary in `params`.
+        """
+        return {"distance": "euclidean"}
+
 
 # overwrite sklearn internal checks, this is really hacky
 # we now need to replace: check_array.__wrapped__.__code__ since it's
