@@ -1024,9 +1024,16 @@ class SFA(_PanelToPanelTransformer):
         return letters
 
     @classmethod
-    def get_test_params(cls):
+    def get_test_params(cls, parameter_set="default"):
         """Return testing parameter settings for the estimator.
 
+        Parameters
+        ----------
+        parameter_set : str, default="default"
+            Name of the set of test parameters to return, for use in tests. If no
+            special parameters are defined for a value, will return `"default"` set.
+
+
         Returns
         -------
         params : dict or list of dict, default = {}
