@@ -1,21 +1,20 @@
-#!/usr/bin/env python3 -u
 # -*- coding: utf-8 -*-
+"""Sequence feature extraction transformers."""
 # copyright: sktime developers, BSD-3-Clause License (see LICENSE file)
 
+__author__ = ["mloning"]
+
 import numpy as np
 import pandas as pd
 from joblib import Parallel, delayed
 from sklearn.base import clone
 
-from sktime.transformations.base import (
-    _PanelToPanelTransformer,
-    _PanelToTabularTransformer,
-)
+from sktime.datatypes import convert_to
+from sktime.transformations.base import BaseTransformer
 from sktime.transformations.panel.segment import RandomIntervalSegmenter
-from sktime.utils.validation.panel import check_X
 
 
-class PlateauFinder(_PanelToPanelTransformer):
+class PlateauFinder(BaseTransformer):
     """Plateau finder transformer.
 
     Transformer that finds segments of the same given value, plateau in
@@ -32,14 +31,24 @@ class PlateauFinder(_PanelToPanelTransformer):
         finder.
     """
 
-    _tags = {"fit_is_empty": True, "univariate-only": True}
+    _tags = {
+        "fit_is_empty": True,
+        "univariate-only": True,
+        "scitype:transform-input": "Series",
+        # what is the scitype of X: Series, or Panel
+        "scitype:transform-output": "Series",
+        # what scitype is returned: Primitives, Series, Panel
+        "scitype:instancewise": False,  # is this an instance-wise transform?
+        "X_inner_mtype": "nested_univ",  # which mtypes do _fit/_predict support for X?
+        "y_inner_mtype": "None",  # which mtypes do _fit/_predict support for X?
+    }
 
     def __init__(self, value=np.nan, min_length=2):
         self.value = value
         self.min_length = min_length
         super(PlateauFinder, self).__init__()
 
-    def transform(self, X, y=None):
+    def _transform(self, X, y=None):
         """Transform X.
 
         Parameters
@@ -52,10 +61,6 @@ class PlateauFinder(_PanelToPanelTransformer):
         Xt : pandas DataFrame
           Transformed pandas DataFrame
         """
-        # input checks
-        self.check_is_fitted()
-        X = check_X(X, enforce_univariate=True, coerce_to_pandas=True)
-
         # get column name
         column_name = X.columns[0]
 
@@ -99,18 +104,28 @@ class PlateauFinder(_PanelToPanelTransformer):
         )
         Xt["%s_starts" % column_prefix] = pd.Series(self._starts)
         Xt["%s_lengths" % column_prefix] = pd.Series(self._lengths)
+
+        Xt = Xt.applymap(lambda x: pd.Series(x))
         return Xt
 
 
-class DerivativeSlopeTransformer(_PanelToPanelTransformer):
+class DerivativeSlopeTransformer(BaseTransformer):
     """Derivative slope transformer."""
 
-    # TODO add docstrings
-    def transform(self, X, y=None):
-        """Transform X."""
-        self.check_is_fitted()
-        X = check_X(X, enforce_univariate=False, coerce_to_pandas=True)
+    _tags = {
+        "fit_is_empty": True,
+        "scitype:transform-input": "Series",
+        # what is the scitype of X: Series, or Panel
+        "scitype:transform-output": "Series",
+        # what scitype is returned: Primitives, Series, Panel
+        "scitype:instancewise": False,  # is this an instance-wise transform?
+        "X_inner_mtype": "nested_univ",  # which mtypes do _fit/_predict support for X?
+        "y_inner_mtype": "None",  # which mtypes do _fit/_predict support for X?
+    }
 
+    # TODO add docstrings
+    def _transform(self, X, y=None):
+        """Transform X."""
         num_cases, num_dim = X.shape
         output_df = pd.DataFrame()
         for dim in range(num_dim):
@@ -145,7 +160,7 @@ def _check_features(features):
         )
 
 
-class RandomIntervalFeatureExtractor(_PanelToTabularTransformer):
+class RandomIntervalFeatureExtractor(BaseTransformer):
     """Random interval feature extractor transform.
 
     Transformer that segments time-series into random intervals
@@ -178,7 +193,17 @@ class RandomIntervalFeatureExtractor(_PanelToTabularTransformer):
         by `np.random`.
     """
 
-    _tags = {"univariate-only": True}
+    _tags = {
+        "fit_is_empty": False,
+        "univariate-only": True,
+        "scitype:transform-input": "Series",
+        # what is the scitype of X: Series, or Panel
+        "scitype:transform-output": "Primitives",
+        # what is the scitype of y: None (not needed), Primitives, Series, Panel
+        "scitype:instancewise": True,  # is this an instance-wise transform?
+        "X_inner_mtype": "nested_univ",  # which mtypes do _fit/_predict support for X?
+        "y_inner_mtype": "pd_Series_Table",  # and for y?
+    }
 
     def __init__(
         self,
@@ -195,7 +220,7 @@ class RandomIntervalFeatureExtractor(_PanelToTabularTransformer):
         self.features = features
         super(RandomIntervalFeatureExtractor, self).__init__()
 
-    def fit(self, X, y=None):
+    def _fit(self, X, y=None):
         """
         Fit transformer, generating random interval indices.
 
@@ -221,10 +246,9 @@ class RandomIntervalFeatureExtractor(_PanelToTabularTransformer):
         self.intervals_ = self._interval_segmenter.intervals_
         self.input_shape_ = self._interval_segmenter.input_shape_
         self._time_index = self._interval_segmenter._time_index
-        self._is_fitted = True
         return self
 
-    def transform(self, X, y=None):
+    def _transform(self, X, y=None):
         """Transform X.
 
         Transform X, segments time-series in each column into random
@@ -233,22 +257,19 @@ class RandomIntervalFeatureExtractor(_PanelToTabularTransformer):
 
         Parameters
         ----------
-        X : nested pandas.DataFrame of shape [n_samples, n_features]
+        X : nested pandas.DataFrame of shape [n_instances, n_features]
             Nested dataframe with time-series in cells.
 
         Returns
         -------
         Xt : pandas.DataFrame
-          Transformed pandas DataFrame with same number of rows and one
-          column for each generated interval.
+          Transformed pandas DataFrame with n_instances rows and one
+            column for each generated interval.
         """
-        # Check is fit had been called
-        self.check_is_fitted()
-
         # Check input of feature calculators, i.e list of functions to be
         # applied to time-series
         features = _check_features(self.features)
-        X = check_X(X, enforce_univariate=True, coerce_to_numpy=True)
+        X = convert_to(X, "numpy3D")
 
         # Check that the input is of the same shape as the one passed
         # during fit.
@@ -262,7 +283,7 @@ class RandomIntervalFeatureExtractor(_PanelToTabularTransformer):
         #     raise ValueError('Indexes of input time-series are different
         #     from what was seen in `fit`')
 
-        n_instances, n_columns, _ = X.shape
+        n_instances, _, _ = X.shape
         n_features = len(features)
 
         intervals = self.intervals_
@@ -301,7 +322,7 @@ class RandomIntervalFeatureExtractor(_PanelToTabularTransformer):
         return Xt
 
 
-class FittedParamExtractor(_PanelToTabularTransformer):
+class FittedParamExtractor(BaseTransformer):
     """Fitted parameter extractor.
 
     Extract parameters of a fitted forecaster as features for a subsequent
@@ -324,7 +345,18 @@ class FittedParamExtractor(_PanelToTabularTransformer):
     """
 
     _required_parameters = ["forecaster"]
-    _tags = {"fit_is_empty": True, "univariate-only": True}
+
+    _tags = {
+        "fit_is_empty": True,
+        "univariate-only": True,
+        "scitype:transform-input": "Series",
+        # what is the scitype of X: Series, or Panel
+        "scitype:transform-output": "Primitives",
+        # what is the scitype of y: None (not needed), Primitives, Series, Panel
+        "scitype:instancewise": True,  # is this an instance-wise transform?
+        "X_inner_mtype": "nested_univ",  # which mtypes do _fit/_predict support for X?
+        "y_inner_mtype": "None",  # which mtypes do _fit/_predict support for y?
+    }
 
     def __init__(self, forecaster, param_names, n_jobs=None):
         self.forecaster = forecaster
@@ -332,23 +364,21 @@ class FittedParamExtractor(_PanelToTabularTransformer):
         self.n_jobs = n_jobs
         super(FittedParamExtractor, self).__init__()
 
-    def transform(self, X, y=None):
+    def _transform(self, X, y=None):
         """Transform X.
 
         Parameters
         ----------
         X : pd.DataFrame
             Univariate time series to transform.
-        y : pd.DataFrame, optional (default=False)
-            Exogenous variables
+        y : ignored argument for interface compatibility
+            Additional data, e.g., labels for transformation
 
         Returns
         -------
         Xt : pd.DataFrame
             Extracted parameters; columns are parameter values
         """
-        self.check_is_fitted()
-        X = check_X(X, enforce_univariate=True)
         param_names = self._check_param_names(self.param_names)
         n_instances = X.shape[0]
 
