@@ -103,7 +103,7 @@ class BoxCoxTransformer(BaseTransformer):
         "X_inner_mtype": "np.ndarray",  # which mtypes do _fit/_predict support for X?
         "y_inner_mtype": "None",  # which mtypes do _fit/_predict support for y?
         "transform-returns-same-time-index": True,
-        "fit-in-transform": False,
+        "fit_is_empty": False,
         "univariate-only": True,
         "capability:inverse_transform": True,
     }
@@ -225,7 +225,7 @@ class LogTransformer(BaseTransformer):
         "X_inner_mtype": "np.ndarray",  # which mtypes do _fit/_predict support for X?
         "y_inner_mtype": "None",  # which mtypes do _fit/_predict support for y?
         "transform-returns-same-time-index": True,
-        "fit-in-transform": True,
+        "fit_is_empty": True,
         "univariate-only": False,
         "capability:inverse_transform": True,
     }
